@@ -1,12 +1,12 @@
 from pathlib import Path
 from typing import List
 
-from pyconverters_grobid.grobid import GrobidConverter, GrobidParameters
+from pyconverters_grobid.grobid import GrobidConverter, GrobidParameters, InputFormat
 from pymultirole_plugins.v1.schema import Document, DocumentList
 from starlette.datastructures import UploadFile
 
 
-def test_grobid_xml():
+def test_grobid_pdf():
     converter = GrobidConverter()
     parameters = GrobidParameters(sentences=True, citations=True)
     testdir = Path(__file__).parent
@@ -26,3 +26,17 @@ def test_grobid_xml():
     dl = DocumentList(__root__=docs)
     with json_file.open("w") as fout:
         print(dl.json(exclude_none=True, exclude_unset=True, indent=2), file=fout)
+
+
+def test_grobid_list():
+    converter = GrobidConverter()
+    parameters = GrobidParameters(
+        input_format=InputFormat.URL_List, sentences=True, citations=True
+    )
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/listpdfs.txt")
+    with source.open("rb") as fin:
+        docs: List[Document] = converter.convert(
+            UploadFile(source.name, fin, "text/plain"), parameters
+        )
+    assert len(docs) == 2
